## Summary

<!-- Brief description of what this PR does and why -->

## Changes

-

## Testing

- [ ] `make check` passes (lint + typecheck + tests)
- [ ] New tests added for new functionality
- [ ] Manual testing completed

## Type

- [ ] Bug fix
- [ ] New feature
- [ ] Refactor
- [ ] Documentation
- [ ] CI/Build
